#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2011
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------
"""This is a generic runner of python scripts. It can be copied between projects and shouldn't be altered.
The project_specific_pyrunner.py module, that should be placed in the same directory, contains the project specific
settings.
"""

import sys
import logging

from os.path import normpath, realpath, join, isdir, dirname, abspath
from project_specific_pyrunner import get_correct_main_method, get_licenses_dir, display_only_english_licenses
from hak.hak_env_config import initialize_project, general_exception, set_locale

initialize_project()

def get_basedir():
    return normpath(abspath(join(dirname(realpath(__file__)), '..')))

def should_display_license_first():
    licenses_dir = get_licenses_dir(get_basedir())
    return licenses_dir is not None and isdir(licenses_dir)

def display_license(licenses_dir, display_only_english):
    from lappy.license_viewer import LicenseViewer, ReturnCode

    output_dir = get_basedir() # a "license" sub-directory will be appended

    display_lang = None
    if display_only_english:
        display_lang = "en"

    viewer = LicenseViewer(licenses_dir, output_dir, display_lang)
    rc = viewer.display_license()

    if rc != ReturnCode.RC_ACCEPTED and rc != ReturnCode.RC_DECLINED:
        # we decided to skip and return True in this case
        print >> sys.stderr, "WARNING: LicenseViewer returned %d, skipping license agreement check" % rc
        return True

    return rc == ReturnCode.RC_ACCEPTED

@general_exception
def start():
    if should_display_license_first():
        if not display_license(get_licenses_dir(get_basedir()),
                               display_only_english_licenses()):
            print >> sys.stderr, "License was not accepted, aborting."
            sys.exit(1)

    # Setting locale only now and not before because of the license display
    set_locale()

    sys.argv.pop(0)
    main = get_correct_main_method(sys.argv[0].lower())
    rc = main()
    sys.exit(rc)

start()

